@@ -1,11 +1,10 @@
 from mpl_toolkits.mplot3d import Axes3D
 from matplotlib.collections import PolyCollection
 from matplotlib.colors import colorConverter
-import pylab
-import random
+import matplotlib.pyplot as plt
 import numpy as np
 
-fig = pylab.figure()
+fig = plt.figure()
 ax = Axes3D(fig)
 
 cc = lambda arg: colorConverter.to_rgba(arg, alpha=0.6)
@@ -14,7 +13,7 @@ xs = np.arange(0, 10, 0.4)
 verts = []
 zs = [0.0, 1.0, 2.0, 3.0]
 for z in zs:
-    ys = [random.random() for x in xs]
+    ys = np.random.rand(len(xs))
     ys[0], ys[-1] = 0, 0
     verts.append(zip(xs, ys))
 
@@ -27,5 +26,5 @@ ax.set_xlim3d(0, 10)
 ax.set_ylim3d(-1, 4)
 ax.set_zlim3d(0, 1)
 
-pylab.show()
+plt.show()
 
