@@ -13,13 +13,21 @@ from weakref import ref
 major, minor1, minor2, s, tmp = sys.version_info
 
 
-# on some systems, locale.getpreferredencoding returns None, which can break unicode
-preferredencoding = locale.getpreferredencoding()
+# On some systems, locale.getpreferredencoding returns None,
+# which can break unicode; and the sage project reports that
+# some systems have incorrect locale specifications, e.g.,
+# an encoding instead of a valid locale name.
+
+try:
+    preferredencoding = locale.getpreferredencoding()
+except (ValueError, ImportError):
+    preferredencoding = None
 
 def unicode_safe(s):
     if preferredencoding is None: return unicode(s)
     else: return unicode(s, preferredencoding)
 
+
 class converter:
     """
     Base class for handling string -> python type with support for
@@ -772,11 +780,12 @@ class maxdict(dict):
         self.maxsize = maxsize
         self._killkeys = []
     def __setitem__(self, k, v):
-        if len(self)>=self.maxsize:
-            del self[self._killkeys[0]]
-            del self._killkeys[0]
+        if k not in self:
+            if len(self)>=self.maxsize:
+                del self[self._killkeys[0]]
+                del self._killkeys[0]
+            self._killkeys.append(k)
         dict.__setitem__(self, k, v)
-        self._killkeys.append(k)
 
 
 
