@@ -12,10 +12,9 @@ contains all the plot elements.  The following classes are defined
 
 """
 import numpy as np
-import time
 
 import artist
-from artist import Artist
+from artist import Artist, allow_rasterization
 from axes import Axes, SubplotBase, subplot_class_factory
 from cbook import flatten, allequal, Stack, iterable, dedent
 import _image
@@ -33,6 +32,7 @@ from matplotlib.blocking_input import BlockingMouseInput, BlockingKeyMouseInput
 
 import matplotlib.cbook as cbook
 
+
 class SubplotParams:
     """
     A class to hold the parameters for a subplot
@@ -298,7 +298,7 @@ class Figure(Artist):
 
         Example::
 
-          fig.subtitle('this is the figure title', fontsize=12)
+          fig.suptitle('this is the figure title', fontsize=12)
         """
         x = kwargs.pop('x', 0.5)
         y = kwargs.pop('y', 0.98)
@@ -726,6 +726,7 @@ class Figure(Artist):
         """
         self.clf()
 
+    @allow_rasterization
     def draw(self, renderer):
         """
         Render the figure using :class:`matplotlib.backend_bases.RendererBase` instance renderer
@@ -827,28 +828,59 @@ class Figure(Artist):
         (0,0) is the left, bottom of the figure and 1,1 is the right,
         top.
 
-        The legend instance is returned.  The following kwargs are supported
+        Keyword arguments:
 
-        *loc*
-            the location of the legend
-        *numpoints*
-            the number of points in the legend line
-        *prop*
-            a :class:`matplotlib.font_manager.FontProperties` instance
-        *pad*
-            the fractional whitespace inside the legend border
-        *markerscale*
-            the relative size of legend markers vs. original
-        *shadow*
-            if True, draw a shadow behind legend
-        *labelsep*
-            the vertical space between the legend entries
-        *handlelen*
-            the length of the legend lines
-        *handletextsep*
-            the space between the legend line and legend text
-        *axespad*
-            the border between the axes and legend edge
+          *prop*: [ None | FontProperties | dict ]
+            A :class:`matplotlib.font_manager.FontProperties`
+            instance. If *prop* is a dictionary, a new instance will be
+            created with *prop*. If *None*, use rc settings.
+
+          *numpoints*: integer
+            The number of points in the legend line, default is 4
+
+          *scatterpoints*: integer
+            The number of points in the legend line, default is 4
+
+          *scatteroffsets*: list of floats
+            a list of yoffsets for scatter symbols in legend
+
+          *markerscale*: [ None | scalar ]
+            The relative size of legend markers vs. original. If *None*, use rc
+            settings.
+
+          *fancybox*: [ None | False | True ]
+            if True, draw a frame with a round fancybox.  If None, use rc
+
+          *shadow*: [ None | False | True ]
+            If *True*, draw a shadow behind legend. If *None*, use rc settings.
+
+          *ncol* : integer
+            number of columns. default is 1
+
+          *mode* : [ "expand" | None ]
+            if mode is "expand", the legend will be horizontally expanded
+            to fill the axes area (or *bbox_to_anchor*)
+
+          *title* : string
+            the legend title
+
+        Padding and spacing between various elements use following keywords
+        parameters. The dimensions of these values are given as a fraction
+        of the fontsize. Values from rcParams will be used if None.
+
+        ================   ==================================================================
+        Keyword            Description
+        ================   ==================================================================
+        borderpad          the fractional whitespace inside the legend border
+        labelspacing       the vertical space between the legend entries
+        handlelength       the length of the legend handles
+        handletextpad      the pad between the legend handle and text
+        borderaxespad      the pad between the axes and legend border
+        columnspacing      the spacing between columns
+        ================   ==================================================================
+
+
+        **Example:**
 
         .. plot:: mpl_examples/pylab_examples/figlegend_demo.py
         """
@@ -971,6 +1003,16 @@ class Figure(Artist):
             a plot on top of a colored background on a web page.  The
             transparency of these patches will be restored to their
             original values upon exit of this function.
+
+          *bbox_inches*:
+            Bbox in inches. Only the given portion of the figure is
+            saved. If 'tight', try to figure out the tight bbox of
+            the figure.
+
+          *pad_inches*:
+            Amount of padding around the figure when bbox_inches is
+            'tight'.
+
         """
 
         for key in ('dpi', 'facecolor', 'edgecolor'):
@@ -1022,7 +1064,8 @@ class Figure(Artist):
 
     def subplots_adjust(self, *args, **kwargs):
         """
-        fig.subplots_adjust(left=None, bottom=None, right=None, wspace=None, hspace=None)
+        fig.subplots_adjust(left=None, bottom=None, right=None, top=None,
+            wspace=None, hspace=None)
 
         Update the :class:`SubplotParams` with *kwargs* (defaulting to rc where
         None) and update the subplot locations
@@ -1043,11 +1086,12 @@ class Figure(Artist):
                 ax.update_params()
                 ax.set_position(ax.figbox)
 
-    def ginput(self, n=1, timeout=30, show_clicks=True):
+    def ginput(self, n=1, timeout=30, show_clicks=True, mouse_add=1, mouse_pop=3, mouse_stop=2):
         """
         call signature::
 
-          ginput(self, n=1, timeout=30, show_clicks=True)
+          ginput(self, n=1, timeout=30, show_clicks=True,
+                 mouse_add=1, mouse_pop=3, mouse_stop=2)
 
         Blocking call to interact with the figure.
 
@@ -1061,6 +1105,12 @@ class Figure(Artist):
 
         Right clicking cancels last input.
 
+        The buttons used for the various actions (adding points, removing
+        points, terminating the inputs) can be overriden via the
+        arguments *mouse_add*, *mouse_pop* and *mouse_stop*, that give
+        the associated mouse button: 1 for left, 2 for middle, 3 for
+        right.
+
         The keyboard can also be used to select points in case your mouse
         does not have one or more of the buttons.  The delete and backspace
         keys act like right clicking (i.e., remove last point), the enter key
@@ -1068,7 +1118,9 @@ class Figure(Artist):
         manager) selects a point.
         """
 
-        blocking_mouse_input = BlockingMouseInput(self)
+        blocking_mouse_input = BlockingMouseInput(self, mouse_add =mouse_add,
+                                                        mouse_pop =mouse_pop,
+                                                        mouse_stop=mouse_stop)
         return blocking_mouse_input(n=n, timeout=timeout,
                                     show_clicks=show_clicks)
 
@@ -1091,6 +1143,29 @@ class Figure(Artist):
         return blocking_input(timeout=timeout)
 
 
+
+    def get_tightbbox(self, renderer):
+        """
+        Return a (tight) bounding box of the figure in inches.
+
+        It only accounts axes title, axis labels, and axis
+        ticklabels. Needs improvement.
+        """
+
+        bb = []
+        for ax in self.axes:
+            if ax.get_visible():
+                bb.append(ax.get_tightbbox(renderer))
+
+        _bbox = Bbox.union([b for b in bb if b.width!=0 or b.height!=0])
+
+        bbox_inches = TransformedBbox(_bbox,
+                                      Affine2D().scale(1./self.dpi))
+
+        return bbox_inches
+
+
+
 def figaspect(arg):
     """
     Create a figure with specified aspect ratio.  If *arg* is a number,
