@@ -1,4 +1,5 @@
 import math
+import warnings
 
 import numpy as npy
 
@@ -6,16 +7,18 @@ import matplotlib
 rcParams = matplotlib.rcParams
 from matplotlib.artist import kwdocd
 from matplotlib.axes import Axes
+import matplotlib.axis as maxis
 from matplotlib import cbook
 from matplotlib.patches import Circle
 from matplotlib.path import Path
 from matplotlib.ticker import Formatter, Locator
 from matplotlib.transforms import Affine2D, Affine2DBase, Bbox, \
     BboxTransformTo, IdentityTransform, Transform, TransformWrapper
+import matplotlib.spines as mspines
 
 class PolarAxes(Axes):
     """
-    A polar graph projection, where the input dimensions are theta, r.
+    A polar graph projection, where the input dimensions are *theta*, *r*.
 
     Theta starts pointing east and goes anti-clockwise.
     """
@@ -23,23 +26,15 @@ class PolarAxes(Axes):
 
     class PolarTransform(Transform):
         """
-        The base polar transform.  This handles projection theta and r into
-        Cartesian coordinate space, but does not perform the ultimate affine
-        transformation into the correct position.
+        The base polar transform.  This handles projection *theta* and
+        *r* into Cartesian coordinate space *x* and *y*, but does not
+        perform the ultimate affine transformation into the correct
+        position.
         """
         input_dims = 2
         output_dims = 2
         is_separable = False
 
-        def __init__(self, resolution):
-            """
-            Create a new polar transform.  Resolution is the number of steps
-            to interpolate between each input line segment to approximate its
-            path in curved polar space.
-            """
-            Transform.__init__(self)
-            self._resolution = resolution
-
         def transform(self, tr):
             xy   = npy.zeros(tr.shape, npy.float_)
             t    = tr[:, 0:1]
@@ -58,7 +53,7 @@ class PolarAxes(Axes):
             vertices = path.vertices
             if len(vertices) == 2 and vertices[0, 0] == vertices[1, 0]:
                 return Path(self.transform(vertices), path.codes)
-            ipath = path.interpolated(self._resolution)
+            ipath = path.interpolated(path._interpolation_steps)
             return Path(self.transform(ipath.vertices), ipath.codes)
         transform_path.__doc__ = Transform.transform_path.__doc__
 
@@ -66,7 +61,7 @@ class PolarAxes(Axes):
         transform_path_non_affine.__doc__ = Transform.transform_path_non_affine.__doc__
 
         def inverted(self):
-            return PolarAxes.InvertedPolarTransform(self._resolution)
+            return PolarAxes.InvertedPolarTransform()
         inverted.__doc__ = Transform.inverted.__doc__
 
     class PolarAffine(Affine2DBase):
@@ -75,9 +70,10 @@ class PolarAxes(Axes):
         that maximum radius rests on the edge of the axes circle.
         """
         def __init__(self, scale_transform, limits):
-            """
-            limits is the view limit of the data.  The only part of
+            u"""
+            *limits* is the view limit of the data.  The only part of
             its bounds that is used is ymax (for the radius maximum).
+            The theta range is always fixed to (0, 2\u03c0).
             """
             Affine2DBase.__init__(self)
             self._scale_transform = scale_transform
@@ -101,16 +97,12 @@ class PolarAxes(Axes):
     class InvertedPolarTransform(Transform):
         """
         The inverse of the polar transform, mapping Cartesian
-        coordinate space back to t and r.
+        coordinate space *x* and *y* back to *theta* and *r*.
         """
         input_dims = 2
         output_dims = 2
         is_separable = False
 
-        def __init__(self, resolution):
-            Transform.__init__(self)
-            self._resolution = resolution
-
         def transform(self, xy):
             x = xy[:, 0:1]
             y = xy[:, 1:]
@@ -121,25 +113,35 @@ class PolarAxes(Axes):
         transform.__doc__ = Transform.transform.__doc__
 
         def inverted(self):
-            return PolarAxes.PolarTransform(self._resolution)
+            return PolarAxes.PolarTransform()
         inverted.__doc__ = Transform.inverted.__doc__
 
     class ThetaFormatter(Formatter):
-        """
-        Used to format the theta tick labels.  Converts the native
-        unit of radians into degrees and adds a degree symbol.
+        u"""
+        Used to format the *theta* tick labels.  Converts the
+        native unit of radians into degrees and adds a degree symbol
+        (\u00b0).
         """
         def __call__(self, x, pos=None):
             # \u00b0 : degree symbol
-            return u"%d\u00b0" % ((x / npy.pi) * 180.0)
+            if rcParams['text.usetex'] and not rcParams['text.latex.unicode']:
+                return r"$%0.0f^\circ$" % ((x / npy.pi) * 180.0)
+            else:
+                # we use unicode, rather than mathtext with \circ, so
+                # that it will work correctly with any arbitrary font
+                # (assuming it has a degree sign), whereas $5\circ$
+                # will only work correctly with one of the supported
+                # math fonts (Computer Modern and STIX)
+                return u"%0.0f\u00b0" % ((x / npy.pi) * 180.0)
 
     class RadialLocator(Locator):
         """
         Used to locate radius ticks.
 
         Ensures that all ticks are strictly positive.  For all other
-        tasks, it delegates to the base Locator (which may be
-        different depending on the scale of the r-axis.
+        tasks, it delegates to the base
+        :class:`~matplotlib.ticker.Locator` (which may be different
+        depending on the scale of the *r*-axis.
         """
         def __init__(self, base):
             self.base = base
@@ -160,14 +162,29 @@ class PolarAxes(Axes):
         def refresh(self):
             return self.base.refresh()
 
-    RESOLUTION = 75
+        def view_limits(self, vmin, vmax):
+            vmin, vmax = self.base.view_limits(vmin, vmax)
+            return 0, vmax
+
 
     def __init__(self, *args, **kwargs):
         """
         Create a new Polar Axes for a polar plot.
+
+        The following optional kwargs are supported:
+
+          - *resolution*: The number of points of interpolation between
+            each pair of data points.  Set to 1 to disable
+            interpolation.
         """
 
         self._rpad = 0.05
+        self.resolution = kwargs.pop('resolution', None)
+        if self.resolution not in (None, 1):
+            warnings.warn(
+                """The resolution kwarg to Polar plots is now ignored.
+If you need to interpolate data points, consider running
+cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
         Axes.__init__(self, *args, **kwargs)
         self.set_aspect('equal', adjustable='box', anchor='C')
         self.cla()
@@ -187,6 +204,16 @@ class PolarAxes(Axes):
         self.xaxis.set_ticks_position('none')
         self.yaxis.set_ticks_position('none')
 
+    def _init_axis(self):
+        "move this out of __init__ because non-separable axes don't use it"
+        self.xaxis = maxis.XAxis(self)
+        self.yaxis = maxis.YAxis(self)
+        # Calling polar_axes.xaxis.cla() or polar_axes.xaxis.cla()
+        # results in weird artifacts. Therefore we disable this for
+        # now.
+        # self.spines['polar'].register_axis(self.yaxis)
+        self._update_transScale()
+
     def _set_lim_and_transforms(self):
         self.transAxes = BboxTransformTo(self.bbox)
 
@@ -195,7 +222,7 @@ class PolarAxes(Axes):
         self.transScale = TransformWrapper(IdentityTransform())
 
         # A (possibly non-linear) projection on the (already scaled) data
-        self.transProjection = self.PolarTransform(self.RESOLUTION)
+        self.transProjection = self.PolarTransform()
 
         # An affine transformation on the data, generally to limit the
         # range of the axes
@@ -243,7 +270,8 @@ class PolarAxes(Axes):
             self._yaxis_transform
             )
 
-    def get_xaxis_transform(self):
+    def get_xaxis_transform(self,which='grid'):
+        assert which in ['tick1','tick2','grid']
         return self._xaxis_transform
 
     def get_xaxis_text1_transform(self, pad):
@@ -252,7 +280,8 @@ class PolarAxes(Axes):
     def get_xaxis_text2_transform(self, pad):
         return self._xaxis_text2_transform, 'center', 'center'
 
-    def get_yaxis_transform(self):
+    def get_yaxis_transform(self,which='grid'):
+        assert which in ['tick1','tick2','grid']
         return self._yaxis_transform
 
     def get_yaxis_text1_transform(self, pad):
@@ -264,7 +293,12 @@ class PolarAxes(Axes):
     def _gen_axes_patch(self):
         return Circle((0.5, 0.5), 0.5)
 
+    def _gen_axes_spines(self):
+        return {'polar':mspines.Spine.circular_spine(self,
+                                                     (0.5, 0.5), 0.5)}
+
     def set_rmax(self, rmax):
+        self.viewLim.y0 = 0
         self.viewLim.y1 = rmax
         angle = self._r_label1_position.to_values()[4]
         self._r_label1_position.clear().translate(
@@ -287,24 +321,26 @@ class PolarAxes(Axes):
                        **kwargs):
         """
         Set the angles at which to place the theta grids (these
-        gridlines are equal along the theta dimension).  angles is in
-        degrees
+        gridlines are equal along the theta dimension).  *angles* is in
+        degrees.
 
-        labels, if not None, is a len(angles) list of strings of the
-        labels to use at each angle.
+        *labels*, if not None, is a ``len(angles)`` list of strings of
+        the labels to use at each angle.
 
-        if labels is None, the labels with be fmt%%angle
+        If *labels* is None, the labels will be ``fmt %% angle``
 
-        frac is the fraction of the polar axes radius at which to
-        place the label (1 is the edge).Eg 1.05 isd outside the axes
-        and 0.95 is inside the axes
+        *frac* is the fraction of the polar axes radius at which to
+        place the label (1 is the edge). Eg. 1.05 is outside the axes
+        and 0.95 is inside the axes.
 
-        Return value is a list of lines, labels where the lines are
-        lines.Line2D instances and the labels are Text
-        instances:
+        Return value is a list of tuples (*line*, *label*), where
+        *line* is :class:`~matplotlib.lines.Line2D` instances and the
+        *label* is :class:`~matplotlib.text.Text` instances.
+
+        kwargs are optional text properties for the labels:
 
-        kwargs are optional text properties for the labels
         %(Text)s
+
         ACCEPTS: sequence of floats
         """
         angles = npy.asarray(angles, npy.float_)
@@ -321,23 +357,25 @@ class PolarAxes(Axes):
 
     def set_rgrids(self, radii, labels=None, angle=None, rpad=None, **kwargs):
         """
-        set the radial locations and labels of the r grids
+        Set the radial locations and labels of the *r* grids.
 
-        The labels will appear at radial distances radii at angle
+        The labels will appear at radial distances *radii* at the
+        given *angle* in degrees.
 
-        labels, if not None, is a len(radii) list of strings of the
-        labels to use at each angle.
+        *labels*, if not None, is a ``len(radii)`` list of strings of the
+        labels to use at each radius.
 
-        if labels is None, the self.rformatter will be used
+        If *labels* is None, the built-in formatter will be used.
 
-        rpad is a fraction of the max of radii which will pad each of
+        *rpad* is a fraction of the max of *radii* which will pad each of
         the radial labels in the radial direction.
 
-        Return value is a list of lines, labels where the lines are
-        lines.Line2D instances and the labels are text.Text
-        instances
+        Return value is a list of tuples (*line*, *label*), where
+        *line* is :class:`~matplotlib.lines.Line2D` instances and the
+        *label* is :class:`~matplotlib.text.Text` instances.
+
+        kwargs are optional text properties for the labels:
 
-        kwargs control the rgrid Text label properties:
         %(Text)s
 
         ACCEPTS: sequence of floats
@@ -359,7 +397,7 @@ class PolarAxes(Axes):
         self._r_label2_position.clear().translate(angle, -self._rpad * rmax)
         for t in self.yaxis.get_ticklabels():
             t.update(kwargs)
-        return self.yaxis.get_ticklines(), self.yaxis.get_ticklabels()
+        return self.yaxis.get_gridlines(), self.yaxis.get_ticklabels()
 
     set_rgrids.__doc__ = cbook.dedent(set_rgrids.__doc__) % kwdocd
 
@@ -372,7 +410,10 @@ class PolarAxes(Axes):
         self.viewLim.intervalx = (0.0, npy.pi * 2.0)
 
     def format_coord(self, theta, r):
-        'return a format string formatting the coordinate'
+        """
+        Return a format string formatting the coordinate using Unicode
+        characters.
+        """
         theta /= math.pi
         # \u03b8: lower-case theta
         # \u03c0: lower-case pi
